@@ -2583,12 +2583,16 @@ def _generate_convert_help():
     """
     ).strip()
     recipe_names = [
-        n for n in dir(recipes) if not n.startswith("_") and n not in ("json", "parser")
+        n
+        for n in dir(recipes)
+        if not n.startswith("_")
+        and n not in ("json", "parser")
+        and callable(getattr(recipes, n))
     ]
     for name in recipe_names:
         fn = getattr(recipes, name)
-        help += "\n\nr.{}{}\n\n  {}".format(
-            name, str(inspect.signature(fn)), fn.__doc__
+        help += "\n\nr.{}{}\n\n\b{}".format(
+            name, str(inspect.signature(fn)), fn.__doc__.rstrip()
         )
     help += "\n\n"
     help += textwrap.dedent(
@@ -2672,7 +2676,12 @@ def convert(
         raise click.ClickException(str(e))
     if dry_run:
         # Pull first 20 values for first column and preview them
-        db.conn.create_function("preview_transform", 1, lambda v: fn(v) if v else v)
+        preview = lambda v: fn(v) if v else v  # noqa: E731
+        if multi:
+            preview = (
+                lambda v: json.dumps(fn(v), default=repr) if v else v
+            )  # noqa: E731
+        db.conn.create_function("preview_transform", 1, preview)
         sql = """
             select
                 [{column}] as value,
