@@ -15,7 +15,7 @@ def test_recreate_ignored_for_in_memory():
 def test_recreate_not_allowed_for_connection():
     conn = sqlite3.connect(":memory:")
     with pytest.raises(AssertionError):
-        db = Database(conn, recreate=True)
+        Database(conn, recreate=True)
 
 
 @pytest.mark.parametrize(
